import { HttpClient } from '@angular/common/http';
import { EventEmitter } from '@angular/core';
import { Observable } from 'rxjs/Observable';
import { Router } from '@angular/router';
import { AuthConfiguration, OpenIDImplicitFlowConfiguration } from '../modules/auth.configuration';
import { OidcSecurityCheckSession } from './oidc.security.check-session';
import { OidcSecuritySilentRenew } from './oidc.security.silent-renew';
import { OidcSecurityUserService } from './oidc.security.user-service';
import { OidcSecurityCommon } from './oidc.security.common';
import { AuthWellKnownEndpoints } from './auth.well-known-endpoints';
import { AuthorizationResult } from '../models/authorization-result.enum';
import { StateValidationService } from './oidc-security-state-validation.service';
export declare class OidcSecurityService {
    private platformId;
    private http;
    private stateValidationService;
    private authConfiguration;
    private router;
    private oidcSecurityCheckSession;
    private oidcSecuritySilentRenew;
    private oidcSecurityUserService;
    private oidcSecurityCommon;
    private authWellKnownEndpoints;
    onModuleSetup: EventEmitter<any>;
    onAuthorizationResult: EventEmitter<AuthorizationResult>;
    checkSessionChanged: boolean;
    moduleSetup: boolean;
    private _isAuthorized;
    private _isAuthorizedValue;
    private lastUserData;
    private _userData;
    private oidcSecurityValidation;
    private authWellKnownEndpointsLoaded;
    private runTokenValidationRunning;
    constructor(platformId: Object, http: HttpClient, stateValidationService: StateValidationService, authConfiguration: AuthConfiguration, router: Router, oidcSecurityCheckSession: OidcSecurityCheckSession, oidcSecuritySilentRenew: OidcSecuritySilentRenew, oidcSecurityUserService: OidcSecurityUserService, oidcSecurityCommon: OidcSecurityCommon, authWellKnownEndpoints: AuthWellKnownEndpoints);
    setupModule(openIDImplicitFlowConfiguration: OpenIDImplicitFlowConfiguration): void;
    getUserData(): Observable<any>;
    getIsAuthorized(): Observable<boolean>;
    getToken(): any;
    getIdToken(): any;
    getPayloadFromIdToken(encode?: boolean): any;
    setState(state: string): void;
    getState(): string;
    setCustomRequestParameters(params: {
        [key: string]: string | number | boolean;
    }): void;
    authorize(): void;
    authorizedCallback(hash?: string): void;
    getUserinfo(isRenewProcess?: boolean, result?: any, id_token?: any, decoded_id_token?: any): Observable<boolean>;
    logoff(): void;
    refreshSession(): void;
    handleError(error: any): void;
    private getValidatedStateResult(result, jwtKeys);
    private setUserData(userData);
    private setIsAuthorized(isAuthorized);
    private setAuthorizationData(access_token, id_token);
    private createAuthorizeUrl(nonce, state, authorization_endpoint, prompt?);
    private createEndSessionUrl(end_session_endpoint, id_token_hint);
    private resetAuthorizationData(isRenewProcess);
    private onCheckSessionChanged();
    private onWellKnownEndpointsLoaded();
    private onUserDataChanged();
    private getSigningKeys();
    private handleErrorGetSigningKeys(error);
    private runTokenValidation();
}
